pub enum Many<T> {
Data(Vec<T>),
NotFetched,
None,
}Expand description
Enum for defining one-to-many or many-to-many relationships
Variants
Data(Vec<T>)
This holds the created/fetched data in a vector
NotFetched
For when the data exists but is not fetched
None
For when you have no data to fill or fetch from the DB
Implementations
Sourceimpl<T> Many<T>
impl<T> Many<T>
Sourcepub fn data(&self) -> Result<&Vec<T>>
pub fn data(&self) -> Result<&Vec<T>>
Returns the Vec of data if they exist and were fetched/created
Sourcepub fn data_mut(&mut self) -> Result<&mut Vec<T>>
pub fn data_mut(&mut self) -> Result<&mut Vec<T>>
Returns the mutable Vec of data if they exist and were fetched/created
Sourcepub fn is_not_fetched(&self) -> bool
pub fn is_not_fetched(&self) -> bool
Is this a NotFetched variant?